##############################################################################
#
# ZPhotoSlidesFolder for Zope
#
# Copyright (c) 2001 Logic Etc, Inc.  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Florent Carlier  florent.carlier@insa-rennes.fr
#   Jean-Franois Roche jfroche@jfroche.be
#
##############################################################################

"""ZPhotoSlides Folder
"""

from Globals import Persistent
from Globals import package_home
from OFS.ObjectManager import ObjectManager
from OFS.SimpleItem import Item
from OFS.PropertyManager import PropertyManager
from OFS.FindSupport import FindSupport
from AccessControl.Role import RoleManager
from AccessControl import ClassSecurityInfo
from Globals import MessageDialog
from Globals import InitializeClass, DTMLFile,HTMLFile
from ZPhotoSlides import ZPhotoSlides
import os

def upload_file(path,_prefix=None):
        if _prefix is None: _prefix=SOFTWARE_HOME
        elif type(_prefix) is not type(''):
            _prefix=package_home(_prefix)
        path = os.path.join(_prefix, path)

        file=open(path, 'rb')
        data=file.read()
        file.close()
        return data

class ZPhotoSlidesFolder(
                         ObjectManager,
                         PropertyManager,
                         RoleManager,
                         Item,
                         FindSupport):
    """ZPhotoSlides Folder object implementation."""

    manage_options = (
                       {'label': 'Manage ZPhotoSlides',    'action':'manage_main'},
	               {'label': 'Properties',       'action': 'manage_props'},
		       {'label': 'View',       'action': 'index_html'},
		       {'label': 'About this product',   'action': 'about'},
                       {'label': 'Security',   'action': 'manage_access'},
                       {'label': 'Undo', 'action': 'manage_UndoForm'},
                       {'label': 'Ownership', 'action': 'manage_owner'}
		     )
 
    meta_type = "ZPhotoSlides Folder"
    manage_props = DTMLFile('dtml/ZPhotoSlidesFolderEdit',globals()) # edit main properties
    about = DTMLFile('dtml/about',globals())                         # about us
    css_file = HTMLFile('dtml/stylesheet_demo.css',globals())        # main css file
    manage_main = DTMLFile('dtml/list_zphotoslides',globals())
    
    _properties = (
        {'id':'title', 'type': 'string', 'mode': 'w'},
        )

    security=ClassSecurityInfo()

    def __init__(self, id, title, description):

        self.version = '0.1'
        self.id = id
        self.title = title
        self.description = description
        self.actual_css = 'stylesheet_base_css'
        self.update_date = '05/12/2002'
        self.manage_addFolder('css', 'Thumbnails', createPublic=0, createUserF=0, REQUEST=None)
	self.css._setProperty('amount_css',1,'int')
	self.css.manage_addDTMLMethod('stylesheet_base_css', 'Main ZPhotoSlidesFolder Stylesheet', upload_file('dtml/stylesheet_demo.css.dtml', globals()), REQUEST=None)
	

    security.declareProtected('Access contents information', 'zphotoslidesIds')
    def manage_edit(self, title,description,REQUEST):
        """Edit the main properties..."""
        self.title = title
        self.description = description
        if REQUEST is not None:
            return MessageDialog(
                title = 'Edited',
                message = "Properties for %s changed." % self.id,
                action = './manage_props',
                )

    security.declareProtected('Access contents information', 'zphotoslidesIds')
    def zphotoslidesIds(self):
        """Return list of ZPhotoSlides in this folder."""
        return self.objectIds(['ZPhotoSlides'])

    def image_select(self):
        return [''] + self.photoIds()

    security.declareProtected('Access contents information', 'numZPhotoSlides')
    def numZPhotoSlides(self):
        """Return number of ZPhotoSlides in folder tree."""
        ZPhotoSlides = len(self.objectIds(['ZPhotoSlides']))
        for folder in self.objectValues(['ZPhotoSlides Folder']):
            ZPhotoSlides = ZPhotoSlides + folder.numZPhotoSlides()
        return ZPhotoSlides

    security.declareProtected('Access contents information', 'nextZPhotoSlidesFolder')
    def nextZPhotoSlidesFolder(self):
        """Return next ZPhotoSlides Folder."""
        id = self.getId()
        folderIds = self.aq_parent.objectIds(['ZPhotoSlides Folder'])
        folderIds.sort()
        if id == folderIds[-1]:
            return None
        return getattr(self.aq_parent, folderIds[folderIds.index(id)+1])

    security.declareProtected('Access contents information', 'prevZPhotoSlidesFolder')
    def prevZPhotoSlidesFolder(self):
        """Return previous ZPhotoSlides Folder."""
        id = self.getId()
        folderIds = self.aq_parent.objectIds(['ZPhotoSlides Folder'])
        folderIds.sort()
        if id == folderIds[0]:
            return None
        return getattr(self.aq_parent, folderIds[folderIds.index(id)-1])
    
manage_addZPhotoSlidesFolderForm = DTMLFile('dtml/addZPhotoSlidesFolderForm', globals())

def manage_addZPhotoSlidesFolder(dispatcher, id, title,description, REQUEST=None):
    """Add ZPhotoSlides Folder object"""
    dest = dispatcher.Destination()
    dest._setObject(id, ZPhotoSlidesFolder(id, title,description))

    self = dest._getOb(id)
    index_folder_html = DTMLFile('dtml/index_folder_html', globals())
    self.manage_addDTMLMethod('index_html', '')
    self._getOb('index_html').manage_edit(index_folder_html, 'Sample Folder View')

    if REQUEST is not None:
        try:    url=dispatcher.DestinationURL()
        except: url=REQUEST['URL1']
        REQUEST.RESPONSE.redirect('%s/%s/manage_props' % (url,id))
    return id

InitializeClass(ZPhotoSlidesFolder)
